"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verify = exports.signAttestation = exports.sign = exports.getRekorBaseUrl = void 0;
/*
Copyright 2022 The Sigstore Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
const client_1 = require("./client");
const identity_1 = __importDefault(require("./identity"));
const sign_1 = require("./sign");
const bundle_1 = require("./types/bundle");
const verify_1 = require("./verify");
function getRekorBaseUrl(options) {
    return client_1.Rekor.getBaseUrl(options === null || options === void 0 ? void 0 : options.rekorBaseURL);
}
exports.getRekorBaseUrl = getRekorBaseUrl;
async function sign(payload, options = {}) {
    const fulcio = new client_1.Fulcio({ baseURL: options.fulcioBaseURL });
    const rekor = new client_1.Rekor({ baseURL: options.rekorBaseURL });
    const idps = configureIdentityProviders(options);
    const signer = new sign_1.Signer({
        fulcio,
        rekor,
        identityProviders: idps,
    });
    const bundle = await signer.signBlob(payload);
    return bundle_1.Bundle.toJSON(bundle);
}
exports.sign = sign;
async function signAttestation(payload, payloadType, options = {}) {
    const fulcio = new client_1.Fulcio({ baseURL: options.fulcioBaseURL });
    const rekor = new client_1.Rekor({ baseURL: options.rekorBaseURL });
    const idps = configureIdentityProviders(options);
    const signer = new sign_1.Signer({
        fulcio,
        rekor,
        identityProviders: idps,
    });
    const bundle = await signer.signAttestation(payload, payloadType);
    return bundle_1.Bundle.toJSON(bundle);
}
exports.signAttestation = signAttestation;
async function verify(bundle, data, options = {}) {
    const rekor = new client_1.Rekor({ baseURL: options.rekorBaseURL });
    const verifier = new verify_1.Verifier({ rekor });
    const b = bundle_1.Bundle.fromJSON(bundle);
    return verifier.verify(b, data);
}
exports.verify = verify;
// Translates the IdenityProviderOptions into a list of Providers which
// should be queried to retrieve an identity token.
function configureIdentityProviders(options) {
    const idps = [];
    const token = options.identityToken;
    // If an explicit identity token is provided, use that. Setup a dummy
    // provider that just returns the token. Otherwise, setup the CI context
    // provider and (optionally) the OAuth provider.
    if (token) {
        idps.push({ getToken: () => Promise.resolve(token) });
    }
    else {
        idps.push(identity_1.default.ciContextProvider());
        if (options.oidcIssuer && options.oidcClientID) {
            idps.push(identity_1.default.oauthProvider(options.oidcIssuer, options.oidcClientID, options.oidcClientSecret));
        }
    }
    return idps;
}
