"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rekor = void 0;
/*
Copyright 2022 The Sigstore Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
const util_1 = require("../../util");
const INTOTO_KIND = 'intoto';
const HASHEDREKORD_KIND = 'hashedrekord';
exports.rekor = {
    toProposedIntotoEntry: (envelope, certificate) => {
        // Double-encode payload and signature cause that's what Rekor expects
        const payload = util_1.encoding.base64Encode(envelope.payload.toString('base64'));
        const signature = util_1.encoding.base64Encode(envelope.signatures[0].sig.toString('base64'));
        const b64Certificate = util_1.encoding.base64Encode(certificate);
        const hash = util_1.crypto.hash(JSON.stringify(envelope.payload)).toString('hex');
        return {
            apiVersion: '0.0.2',
            kind: 'intoto',
            spec: {
                content: {
                    envelope: {
                        payloadType: envelope.payloadType,
                        payload: payload,
                        signatures: [
                            { keyid: '', sig: signature, publicKey: b64Certificate },
                        ],
                    },
                    hash: { algorithm: 'sha256', value: hash },
                },
            },
        };
    },
    toProposedHashedRekordEntry: (digest, signature, certificate) => {
        const b64Digest = digest.toString('hex');
        const b64Signature = signature.toString('base64');
        const b64Certificate = util_1.encoding.base64Encode(certificate);
        return {
            apiVersion: '0.0.1',
            kind: 'hashedrekord',
            spec: {
                data: {
                    hash: {
                        algorithm: 'sha256',
                        value: b64Digest,
                    },
                },
                signature: {
                    content: b64Signature,
                    publicKey: {
                        content: b64Certificate,
                    },
                },
            },
        };
    },
};
