"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Verifier = void 0;
const util_1 = require("./util");
class Verifier {
    constructor(options) {
        this.rekor = options.rekor;
    }
    async verify(bundle, data) {
        var _a, _b, _c;
        let signature;
        switch ((_a = bundle.content) === null || _a === void 0 ? void 0 : _a.$case) {
            case 'dsseEnvelope': {
                const payloadType = bundle.content.dsseEnvelope.payloadType;
                const payload = bundle.content.dsseEnvelope.payload;
                data = util_1.dsse.preAuthEncoding(payloadType, payload);
                if (bundle.content.dsseEnvelope.signatures.length !== 1) {
                    throw new Error('No signatures found in bundle');
                }
                signature = bundle.content.dsseEnvelope.signatures[0].sig;
                break;
            }
            case 'messageSignature':
                signature = bundle.content.messageSignature.signature;
                break;
            default:
                throw new Error('Bundle is invalid');
        }
        if (((_c = (_b = bundle.verificationMaterial) === null || _b === void 0 ? void 0 : _b.content) === null || _c === void 0 ? void 0 : _c.$case) !== 'x509CertificateChain') {
            throw new Error('No certificate found in bundle');
        }
        const certificate = bundle.verificationMaterial.content.x509CertificateChain.certificates[0];
        const cert = util_1.pem.fromDER(certificate.derBytes);
        if (!data) {
            throw new Error('No data to verify');
        }
        return util_1.crypto.verifyBlob(data, cert, signature);
    }
}
exports.Verifier = Verifier;
